@@ -298,6 +298,10 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     if not execute: cmd = [cmd, cleancmd] if clean else [cmd]
     else: cmd = [execute + " " + basename]
 
+    ftargets = [t + ".force" for t in target]
+    if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
+        cmd = ["mv %s %s" %(f,t) for f,t in zip(ftargets,target)]
+
     gen = lambda source, target, env, for_signature: sig if for_signature else cmd 
     return env.Command(target, source + [scons], CommandGeneratorAction(gen,{}))
 
@@ -351,7 +355,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     env.Default(targets)
 
     ftargets = [t + ".force" for t in targets]
-    if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
+    if "print" not in args and reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
         for f,t in zip(ftargets,targets): 
             print "Move(%s,%s)"%(f,t)
             shutil.move(f,t)
